/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.hive;

import com.facebook.presto.tests.AbstractTestDistributedQueries;
import com.google.common.collect.ImmutableMap;

import java.util.Optional;

import static io.airlift.tpch.TpchTable.getTables;

public class TestHiveDistributedQueriesWithOptimizedRepartitioning
        extends AbstractTestDistributedQueries
{
    public TestHiveDistributedQueriesWithOptimizedRepartitioning()
    {
        super(() -> HiveQueryRunner.createQueryRunner(
                getTables(),
                ImmutableMap.of(
                        "experimental.optimized-repartitioning", "true",
                        // Use small SerialiedPages to force flushing
                        "driver.max-page-partitioning-buffer-size", "10000B"),
                Optional.empty()));
    }

    @Override
    protected boolean supportsNotNullColumns()
    {
        return false;
    }

    @Override
    public void testDelete()
    {
        // Hive connector currently does not support row-by-row delete
    }

    // Hive specific tests should normally go in TestHiveIntegrationSmokeTest
}
