/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.hive;

import com.facebook.presto.tests.AbstractTestDistributedQueries;
import com.google.common.collect.ImmutableMap;

import java.util.Optional;

import static com.facebook.presto.hive.HiveQueryRunner.createQueryRunner;
import static io.airlift.tpch.TpchTable.getTables;

public class TestHiveDistributedQueriesWithThriftRpc
        extends AbstractTestDistributedQueries
{
    public TestHiveDistributedQueriesWithThriftRpc()
    {
        super(() -> createQueryRunner(
                getTables(),
                ImmutableMap.of(
                        "internal-communication.task-communication-protocol", "THRIFT",
                        "internal-communication.server-info-communication-protocol", "THRIFT"),
                ImmutableMap.of(),
                Optional.empty()));
    }

    @Override
    protected boolean supportsNotNullColumns()
    {
        return false;
    }

    @Override
    public void testDelete()
    {
        // Hive connector currently does not support row-by-row delete
    }

    // Hive specific tests should normally go in TestHiveIntegrationSmokeTest
}
